@@ -8,7 +8,7 @@ use Data::Validator;
 use Net::OpenStack::Swift::Util qw/uri_escape uri_unescape debugf/;
 use Net::OpenStack::Swift::InnerKeystone;
 use namespace::clean -except => 'meta';
-our $VERSION = "0.08";
+our $VERSION = "0.09";
 
 
 subtype 'Path' => as 'Path::Tiny';
@@ -40,17 +40,16 @@ sub _request {
     my $self = shift;
     my $args = shift;
     
-    my $furl_options = +{
-        timeout => $self->agent_options->{timeout} || 10
-    };
-    $furl_options->{agent} ||= $self->agent_options->{user_agent};
-    my $furl = Furl->new(%{$furl_options});
-
-    # single instance
-    #my $res = $self->agent->request(
+    #my $furl_options = +{
+    #    timeout => $self->agent_options->{timeout} || 10
+    #};
+    #$furl_options->{agent} ||= $self->agent_options->{user_agent};
+    #my $furl = Furl->new(%{$furl_options});
 
     # parallel instance
-    my $res = $furl->request(
+    #my $res = $furl->request(
+    # single instance
+    my $res = $self->agent->request(
         method          => $args->{method},
         url             => $args->{url},
         special_headers => $args->{special_headers},
@@ -796,6 +795,8 @@ cli examples
     $ swift.pl get container1/hello.txt > hello.txt (download file)
     $ swift.pl delete container1/hello.txt
     $ swift.pl delete container1
+    $ swift.pl delete 'container1/*'  (require quoting!)
+    $ swift.pl post static '{"X-Container-Read":".r:*"}'
 
 multi cpu support (parallel downloads and uploads)
 
@@ -806,6 +807,12 @@ creating a .swift.pl.conf file in the user's home directory
 
     $ cat .swift.pl.conf 
     timeout=200
+    user_agent=perl Net::OpenStack::Swift
+    workers=8
+    os_auth_url=
+    os_tenant_name=
+    os_username=
+    os_password=
 
 =head1 Debug
 
